version 10.0

clear

capture log close

log using replication_berlin.log, replace

set mem 500m

set more off

use replication_berlin.dta, clear

label var samecoalition1 "Zurechenbarkeit"
label var nreg2 "Parteiprferenz"
label var cand "Kandidatenprferenz"
label var cand2 "Kandidatenprferenz"
label var popgovs "Regierungspopularitt"
label var bundvote "Wahl einer Partei der Bundesregierung"
label var samec1 "Zurechenbarkeit"
label var interc1s "Zurechenbarkeit x Regierungspopularitt"


************************************
*********Replication****************
************************************

*Tabelle 2: 
tab samecoalition1 year 
tab popgovs

*Tabelle 3:

xtprobit bundvote nreg2 cand2 popgovs, re i(year)
eststo
xtprobit bundvote nreg2 cand2 popgovs samecoalition1 interc1s, re i(year)
eststo

esttab est1 est2 using tab3, b(%9.3f) se(%9.3f) star(* 0.05 ** 0.01) label rtf legend replace

eststo clear



#delimit ;

*bevorzugter Kandidat (1=Kandidat der Bundesregierung, 0=Kandidat der Bundesopposition, .=keine Prferenz) 
* cand

sum nreg2 cand;

*     ****************************************************************  *;
*                           Estimate Probit Model                       *;
*      Y* = b0 + b1X + b2Z + b3XZ + b4Control1 + b5Control2 + epsilon   *;
*     ****************************************************************  *;
iis year;
xtprobit bundvote samecoalition1 popgovs interc1s  nreg2 cand, re i (year); 

*     ****************************************************************  *;
*       Take 10,000 draws from the estimated coefficient vector and     *;
*       variance-covariance matrix.                                     *;
*     ****************************************************************  *;

preserve;
drawnorm MG_b1-MG_b7, seed(1234) n(10000) means(e(b)) cov(e(V)) clear;

*     ****************************************************************  *;
*       To calculate the desired quantities of interest we need to set  *;
*       up a loop.  This is what we do here.                            *;
*     ****************************************************************  *;
*       First, specify what you quantities should be saved and what     *;
*       these quantities should be called.                              *;
*     ****************************************************************  *;

postutil clear;
postfile mypost prob_hat000 lo000 hi000  
                prob_hat001 lo001 hi001  
                prob_hat010 lo010 hi010  
                prob_hat011 lo011 hi011  
                prob_hat100 lo100 hi100  
                prob_hat101 lo101 hi101  
                prob_hat110 lo110 hi110  
                prob_hat111 lo111 hi111 
                diff_hat lod hid 
            using sim , replace;
            noisily display "start";
            
*     ****************************************************************  *;
*       Start loop.  Let `a' be the modifying variable Z and let this   *;
*       run from min to max in the desired increments.                  *;
*     ****************************************************************  *;                                  

local a=-5 ;
while `a' <= 1.5 { ;

    {;

* Define scenario (samecoalition1, nreg2, cand)  Ereignisdaten;

scalar h_samecoalition1=0;
scalar h_nreg2=0;
scalar h_cand=0;
scalar h_constant=1;

*Predicted probs if samecoalition1=0;

    generate x_betahat000 = MG_b1*h_samecoalition1
                            + MG_b2*(`a')
                            + MG_b3*h_samecoalition1*(`a')
                            + MG_b4*h_nreg2
                            + MG_b5*h_cand
                            + MG_b6*h_constant;
    
    generate x_betahat010 = MG_b1*h_samecoalition1
                            + MG_b2*(`a')
                            + MG_b3*h_samecoalition1*(`a')
                            + MG_b4*(h_nreg2+1)
                            + MG_b5*h_cand
                            + MG_b6*h_constant;
    
    generate x_betahat001 = MG_b1*h_samecoalition1
                            + MG_b2*(`a')
                            + MG_b3*h_samecoalition1*(`a')
                            + MG_b4*h_nreg2
                            + MG_b5*(h_cand+1)
                            + MG_b6*h_constant;

    generate x_betahat011 = MG_b1*h_samecoalition1
                            + MG_b2*(`a')
                            + MG_b3*h_samecoalition1*(`a')
                            + MG_b4*(h_nreg2+1)
                            + MG_b5*(h_cand+1)
                            + MG_b6*h_constant;

*Predicted probs if samecoalition1=1;

    generate x_betahat100 = MG_b1*(h_samecoalition1+1)
                            + MG_b2*(`a')
                            + MG_b3*(h_samecoalition1+1)*(`a')
                            + MG_b4*h_nreg2
                            + MG_b5*h_cand
                            + MG_b6*h_constant;
    
    generate x_betahat110 = MG_b1*(h_samecoalition1+1)
                            + MG_b2*(`a')
                            + MG_b3*(h_samecoalition1+1)*(`a')
                            + MG_b4*(h_nreg2+1)
                            + MG_b5*h_cand
                            + MG_b6*h_constant;
    
    generate x_betahat101 = MG_b1*(h_samecoalition1+1)
                            + MG_b2*(`a')
                            + MG_b3*(h_samecoalition1+1)*(`a')
                            + MG_b4*h_nreg2
                            + MG_b5*(h_cand+1)
                            + MG_b6*h_constant;

    generate x_betahat111 = MG_b1*(h_samecoalition1+1)
                            + MG_b2*(`a')
                            + MG_b3*(h_samecoalition1+1)*(`a')
                            + MG_b4*(h_nreg2+1)
                            + MG_b5*(h_cand+1)
                            + MG_b6*h_constant;
 
    gen prob000=normal(x_betahat000);
    gen prob001=normal(x_betahat001);
    gen prob010=normal(x_betahat010);
    gen prob011=normal(x_betahat011);

    gen prob100=normal(x_betahat100);
    gen prob101=normal(x_betahat101);
    gen prob110=normal(x_betahat110);
    gen prob111=normal(x_betahat111);

    gen diff = prob110-prob010;
    egen diffhat=mean(diff);
    
    egen probhat000=mean(prob000);
    egen probhat001=mean(prob001);
    egen probhat010=mean(prob010);
    egen probhat011=mean(prob011);

    egen probhat100=mean(prob100);
    egen probhat101=mean(prob101);
    egen probhat110=mean(prob110);
    egen probhat111=mean(prob111);
    
    tempname prob_hat000 lo000 hi000  
             prob_hat001 lo001 hi001  
             prob_hat010 lo010 hi010  
             prob_hat011 lo011 hi011  
             prob_hat100 lo100 hi100  
             prob_hat101 lo101 hi101  
             prob_hat110 lo110 hi110  
             prob_hat111 lo111 hi111
             diff_hat lod hid;  

    _pctile diff, p(2.5,97.5) ;
    scalar `lod' = r(r1);
    scalar `hid' = r(r2);  


    _pctile prob000, p(2.5,97.5) ;
    scalar `lo000' = r(r1);
    scalar `hi000' = r(r2);  
    _pctile prob001, p(2.5,97.5) ;
    scalar `lo001' = r(r1);
    scalar `hi001' = r(r2);  
    _pctile prob010, p(2.5,97.5) ;
    scalar `lo010' = r(r1);
    scalar `hi010' = r(r2);  
    _pctile prob011, p(2.5,97.5) ;
    scalar `lo011' = r(r1);
    scalar `hi011' = r(r2);  

    _pctile prob100, p(2.5,97.5) ;
    scalar `lo100' = r(r1);
    scalar `hi100' = r(r2);  
    _pctile prob101, p(2.5,97.5) ;
    scalar `lo101' = r(r1);
    scalar `hi101' = r(r2);  
    _pctile prob110, p(2.5,97.5) ;
    scalar `lo110' = r(r1);
    scalar `hi110' = r(r2);  
    _pctile prob111, p(2.5,97.5) ;
    scalar `lo111' = r(r1);
    scalar `hi111' = r(r2);  
   
    scalar `diff_hat'=diffhat;

    scalar `prob_hat000'=probhat000;
    scalar `prob_hat001'=probhat001;
    scalar `prob_hat010'=probhat010;
    scalar `prob_hat011'=probhat011;

    scalar `prob_hat100'=probhat100;
    scalar `prob_hat101'=probhat101;
    scalar `prob_hat110'=probhat110;
    scalar `prob_hat111'=probhat111;
    
    post mypost (`prob_hat000') (`lo000') (`hi000') 
                (`prob_hat001') (`lo001') (`hi001') 
                (`prob_hat010') (`lo010') (`hi010') 
                (`prob_hat011') (`lo011') (`hi011') 
                (`prob_hat100') (`lo100') (`hi100') 
                (`prob_hat101') (`lo101') (`hi101') 
                (`prob_hat110') (`lo110') (`hi110') 
                (`prob_hat111') (`lo111') (`hi111')
                (`diff_hat') (`lod') (`hid');
    };      
    drop x_betahat*  prob0* prob1* probhat* diff diffhat;
    local a=`a'+ 0.1 ;
    display "." _c;
    } ;

display "";

postclose mypost;

*     ****************************************************************  *;                                  
*       Call on posted quantities of interest                           *;
*     ****************************************************************  *;                                  

* Bis hier nur datensatz aus MG_b1-MG_b7 mit n=10000;


*#delimit ;
use sim, clear;

gen expaxis = (_n-1)/10 -5 in 1/66;

local no "000 001 010 011 100 101 110 111";
foreach x of local no {;

graph twoway line prob_hat`x' expaxis , clwidth(medium) clcolor(black) 
|| line lo`x'  expaxis , clpattern(dash) clwidth(thin) clcolor(black) 
|| line hi`x'  expaxis , clpattern(dash) clwidth(thin) clcolor(black) 
 ytitle("") xtitle("")
xlabel(-5(.5)1.5, nogrid labsize(2.5))
yline(0.5,  lcolor(black))
ylabel(0 (0.5) 1, nogrid labsize(2.5) angle(horizontal))
legend(off)
graphregion(color(white))
saving(sim`x'f, replace);
};

graph twoway line diff_hat expaxis , clwidth(medium) clcolor(black) 
|| line lod  expaxis , clpattern(dash) clwidth(thin) clcolor(black) 
|| line hid  expaxis , clpattern(dash) clwidth(thin) clcolor(black) 
 ytitle("") xtitle("")
xlabel(-5(.5)1.5, nogrid labsize(2.5))
yline(0,  lcolor(black))
ylabel(0 (0.5) 1, nogrid labsize(2.5) angle(horizontal))
legend(off)
graphregion(color(white))
saving(simdiff_f, replace);

gr combine sim100f.gph sim101f.gph sim110f.gph sim111f.gph,  
  title("Einfluss der Bundespolitik", span)
  subtitle("(Zurechenbarkeit einfach)", span)
b2title("Zufriedenheit mit der Arbeit der Bundesregierung")
l2title("Pr (Wahl einer Partei der Bundesregierung)")
graphregion(color(white)) saving(sim1sf, replace);

gr combine sim000f.gph sim001f.gph sim010f.gph sim011f.gph,  
  title("Einfluss der Bundespolitik", span)
  subtitle("(Zurechenbarkeit schwierig)", span)
b2title("Zufriedenheit mit der Arbeit der Bundesregierung")
l2title("Pr (Wahl einer Partei der Bundesregierung)")
graphregion(color(white)) saving(sim0sf, replace);
#delimit cr



**************************************************************************************************************************************

****************************************
*******Nach der Replikation der*********
****Abbildungen folgt die Simulation****
**anhand der in Tabelle 3 geschtzten***
********** Koeffizienten****************
****************************************

restore
*use replication_berlin.dta, clear


#delimit ;

*bevorzugter Kandidat (1=Kandidat der Bundesregierung, 0=Kandidat der Bundesopposition oder keine Prferenz) 
* cand2

sum nreg2 cand2;

*     ****************************************************************  *;
*                           Estimate Probit Model                       *;
*      Y* = b0 + b1X + b2Z + b3XZ + b4Control1 + b5Control2 + epsilon   *;
*     ****************************************************************  *;
iis year;
xtprobit bundvote samecoalition1 popgovs interc1s  nreg2 cand2, re i (year); 

*     ****************************************************************  *;
*       Take 10,000 draws from the estimated coefficient vector and     *;
*       variance-covariance matrix.                                     *;
*     ****************************************************************  *;

drawnorm MG_b1-MG_b7, seed(1234) n(10000) means(e(b)) cov(e(V)) clear;

*     ****************************************************************  *;
*       To calculate the desired quantities of interest we need to set  *;
*       up a loop.  This is what we do here.                            *;
*     ****************************************************************  *;
*       First, specify what you quantities should be saved and what     *;
*       these quantities should be called.                              *;
*     ****************************************************************  *;

postutil clear;
postfile mypost prob_hat000 lo000 hi000  
                prob_hat001 lo001 hi001  
                prob_hat010 lo010 hi010  
                prob_hat011 lo011 hi011  
                prob_hat100 lo100 hi100  
                prob_hat101 lo101 hi101  
                prob_hat110 lo110 hi110  
                prob_hat111 lo111 hi111 
                diff_hat lod hid 
            using sim , replace;
            noisily display "start";
            
*     ****************************************************************  *;
*       Start loop.  Let `a' be the modifying variable Z and let this   *;
*       run from min to max in the desired increments.                  *;
*     ****************************************************************  *;                                  

local a=-5 ;
while `a' <= 1.5 { ;

    {;

* Define scenario (samecoalition1, nreg2, cand)  Ereignisdaten;

scalar h_samecoalition1=0;
scalar h_nreg2=0;
scalar h_cand=0;
scalar h_constant=1;

*Predicted probs if samecoalition1=0;

    generate x_betahat000 = MG_b1*h_samecoalition1
                            + MG_b2*(`a')
                            + MG_b3*h_samecoalition1*(`a')
                            + MG_b4*h_nreg2
                            + MG_b5*h_cand
                            + MG_b6*h_constant;
    
    generate x_betahat010 = MG_b1*h_samecoalition1
                            + MG_b2*(`a')
                            + MG_b3*h_samecoalition1*(`a')
                            + MG_b4*(h_nreg2+1)
                            + MG_b5*h_cand
                            + MG_b6*h_constant;
    
    generate x_betahat001 = MG_b1*h_samecoalition1
                            + MG_b2*(`a')
                            + MG_b3*h_samecoalition1*(`a')
                            + MG_b4*h_nreg2
                            + MG_b5*(h_cand+1)
                            + MG_b6*h_constant;

    generate x_betahat011 = MG_b1*h_samecoalition1
                            + MG_b2*(`a')
                            + MG_b3*h_samecoalition1*(`a')
                            + MG_b4*(h_nreg2+1)
                            + MG_b5*(h_cand+1)
                            + MG_b6*h_constant;

*Predicted probs if samecoalition1=1;

    generate x_betahat100 = MG_b1*(h_samecoalition1+1)
                            + MG_b2*(`a')
                            + MG_b3*(h_samecoalition1+1)*(`a')
                            + MG_b4*h_nreg2
                            + MG_b5*h_cand
                            + MG_b6*h_constant;
    
    generate x_betahat110 = MG_b1*(h_samecoalition1+1)
                            + MG_b2*(`a')
                            + MG_b3*(h_samecoalition1+1)*(`a')
                            + MG_b4*(h_nreg2+1)
                            + MG_b5*h_cand
                            + MG_b6*h_constant;
    
    generate x_betahat101 = MG_b1*(h_samecoalition1+1)
                            + MG_b2*(`a')
                            + MG_b3*(h_samecoalition1+1)*(`a')
                            + MG_b4*h_nreg2
                            + MG_b5*(h_cand+1)
                            + MG_b6*h_constant;

    generate x_betahat111 = MG_b1*(h_samecoalition1+1)
                            + MG_b2*(`a')
                            + MG_b3*(h_samecoalition1+1)*(`a')
                            + MG_b4*(h_nreg2+1)
                            + MG_b5*(h_cand+1)
                            + MG_b6*h_constant;
 
    gen prob000=normal(x_betahat000);
    gen prob001=normal(x_betahat001);
    gen prob010=normal(x_betahat010);
    gen prob011=normal(x_betahat011);

    gen prob100=normal(x_betahat100);
    gen prob101=normal(x_betahat101);
    gen prob110=normal(x_betahat110);
    gen prob111=normal(x_betahat111);

    gen diff = prob110-prob010;
    egen diffhat=mean(diff);
    
    egen probhat000=mean(prob000);
    egen probhat001=mean(prob001);
    egen probhat010=mean(prob010);
    egen probhat011=mean(prob011);

    egen probhat100=mean(prob100);
    egen probhat101=mean(prob101);
    egen probhat110=mean(prob110);
    egen probhat111=mean(prob111);
    
    tempname prob_hat000 lo000 hi000  
             prob_hat001 lo001 hi001  
             prob_hat010 lo010 hi010  
             prob_hat011 lo011 hi011  
             prob_hat100 lo100 hi100  
             prob_hat101 lo101 hi101  
             prob_hat110 lo110 hi110  
             prob_hat111 lo111 hi111
             diff_hat lod hid;  

    _pctile diff, p(2.5,97.5) ;
    scalar `lod' = r(r1);
    scalar `hid' = r(r2);  


    _pctile prob000, p(2.5,97.5) ;
    scalar `lo000' = r(r1);
    scalar `hi000' = r(r2);  
    _pctile prob001, p(2.5,97.5) ;
    scalar `lo001' = r(r1);
    scalar `hi001' = r(r2);  
    _pctile prob010, p(2.5,97.5) ;
    scalar `lo010' = r(r1);
    scalar `hi010' = r(r2);  
    _pctile prob011, p(2.5,97.5) ;
    scalar `lo011' = r(r1);
    scalar `hi011' = r(r2);  

    _pctile prob100, p(2.5,97.5) ;
    scalar `lo100' = r(r1);
    scalar `hi100' = r(r2);  
    _pctile prob101, p(2.5,97.5) ;
    scalar `lo101' = r(r1);
    scalar `hi101' = r(r2);  
    _pctile prob110, p(2.5,97.5) ;
    scalar `lo110' = r(r1);
    scalar `hi110' = r(r2);  
    _pctile prob111, p(2.5,97.5) ;
    scalar `lo111' = r(r1);
    scalar `hi111' = r(r2);  
   
    scalar `diff_hat'=diffhat;

    scalar `prob_hat000'=probhat000;
    scalar `prob_hat001'=probhat001;
    scalar `prob_hat010'=probhat010;
    scalar `prob_hat011'=probhat011;

    scalar `prob_hat100'=probhat100;
    scalar `prob_hat101'=probhat101;
    scalar `prob_hat110'=probhat110;
    scalar `prob_hat111'=probhat111;
    
    post mypost (`prob_hat000') (`lo000') (`hi000') 
                (`prob_hat001') (`lo001') (`hi001') 
                (`prob_hat010') (`lo010') (`hi010') 
                (`prob_hat011') (`lo011') (`hi011') 
                (`prob_hat100') (`lo100') (`hi100') 
                (`prob_hat101') (`lo101') (`hi101') 
                (`prob_hat110') (`lo110') (`hi110') 
                (`prob_hat111') (`lo111') (`hi111')
                (`diff_hat') (`lod') (`hid');
    };      
    drop x_betahat*  prob0* prob1* probhat* diff diffhat;
    local a=`a'+ 0.1 ;
    display "." _c;
    } ;

display "";

postclose mypost;

*     ****************************************************************  *;                                  
*       Call on posted quantities of interest                           *;
*     ****************************************************************  *;                                  

* Bis hier nur datensatz aus MG_b1-MG_b7 mit n=10000;


*#delimit ;
use sim, clear;

gen expaxis = (_n-1)/10 -5 in 1/66;

local no "000 001 010 011 100 101 110 111";
foreach x of local no {;

graph twoway line prob_hat`x' expaxis , clwidth(medium) clcolor(black) 
|| line lo`x'  expaxis , clpattern(dash) clwidth(thin) clcolor(black) 
|| line hi`x'  expaxis , clpattern(dash) clwidth(thin) clcolor(black) 
 ytitle("") xtitle("")
xlabel(-5(.5)1.5, nogrid labsize(2.5))
yline(0.5,  lcolor(black))
ylabel(0 (0.5) 1, nogrid labsize(2.5) angle(horizontal))
legend(off)
graphregion(color(white))
saving(sim`x', replace);
};

graph twoway line diff_hat expaxis , clwidth(medium) clcolor(black) 
|| line lod  expaxis , clpattern(dash) clwidth(thin) clcolor(black) 
|| line hid  expaxis , clpattern(dash) clwidth(thin) clcolor(black) 
 ytitle("") xtitle("")
xlabel(-5(.5)1.5, nogrid labsize(2.5))
yline(0,  lcolor(black))
ylabel(0 (0.5) 1, nogrid labsize(2.5) angle(horizontal))
legend(off)
graphregion(color(white))
saving(simdiff, replace);

gr combine sim100.gph sim101.gph sim110.gph sim111.gph,  
  title("Einfluss der Bundespolitik", span)
  subtitle("(Zurechenbarkeit einfach)", span)
b2title("Zufriedenheit mit der Arbeit der Bundesregierung")
l2title("Pr (Wahl einer Partei der Bundesregierung)")
graphregion(color(white)) saving(sim1s, replace);

gr combine sim000.gph sim001.gph sim010.gph sim011.gph,  
  title("Einfluss der Bundespolitik", span)
  subtitle("(Zurechenbarkeit schwierig)", span)
b2title("Zufriedenheit mit der Arbeit der Bundesregierung")
l2title("Pr (Wahl einer Partei der Bundesregierung)")
graphregion(color(white)) saving(sim0s, replace);
#delimit cr












log close

exit
